@@ -1,11 +1,10 @@
-# -*-coding:utf8 -*-
 # This file is part of Mach-O Loader for CLE.
 # Contributed December 2016 by Fraunhofer SIT (https://www.sit.fraunhofer.de/en/).
 
-from .. import Region
+from cle.backends.region import Segment
 
 
-class MachOSegment(Region):
+class MachOSegment(Segment):
     """
     Mach-O Segment
 
@@ -58,3 +57,8 @@ class MachOSegment(Region):
     @property
     def is_executable(self):
         return ((self.initprot | self.maxprot) & 0x04) != 0
+
+    def __repr__(self):
+        return "<{} | offset {:#x}, vaddr {:#x}, size {:#x}>".format(
+            self.segname if self.segname else "Unnamed", self.offset, self.vaddr, self.memsize
+        )
