@@ -1,9 +1,11 @@
-from ..region import Section
+from cle.backends.region import Section
+
 
 class PESection(Section):
     """
     Represents a section for the PE format.
     """
+
     def __init__(self, pe_section, remap_offset=0):
         super().__init__(
             pe_section.Name.decode(),
@@ -13,7 +15,7 @@ class PESection(Section):
         )
 
         self.characteristics = pe_section.Characteristics
-        self.size_of_raw_data = pe_section.SizeOfRawData
+        self.filesize = pe_section.SizeOfRawData
 
     #
     # Public properties
@@ -33,4 +35,4 @@ class PESection(Section):
 
     @property
     def only_contains_uninitialized_data(self):
-        return self.size_of_raw_data == 0
+        return self.filesize == 0
